fisx: TrasmissionTable Class Reference

fisx

TrasmissionTable Class Reference

Class containing a transmission table. More...

`#include <fisx_transmissiontable.h>`

## Detailed Description

Class containing a transmission table.

A transmission table is a tabulated list of energies (in keV) and values between 0 and 1 to represent a transmissio.

It can be used to take into account the transmission of optical elements or windows as provided by manufacturers.

The documentation for this class was generated from the following file:

- fisx_transmissiontable.h